
# Slot: pv_formula


Defines the specific formula to be used to generate the permissible values.

URI: [linkml:pv_formula](https://w3id.org/linkml/pv_formula)


## Domain and Range

enum_definition &#8594;  <sub>0..1</sub> [pv_formula_options](pv_formula_options.md)

## Parents


## Children


## Used by

 * enum_definition

## Other properties

|  |  |  |
| --- | --- | --- |
| **Comments:** | | you cannot have BOTH the permissible_values and permissible_value_formula tag |
|  | | code_set must be supplied for this to be valid |

